/* cobalt vumeter
 *
 * a simplistic, arduino-compatible vumeter 
 * 
 * based upon http://phaq.phunsites.net/2013/09/12/use-arduino-micro-as-isp-with-atmega-on-a-breadboard/
 * 
 * Copyright (c) 2015, Gianpaolo Del Matto, www.phunsites.net
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */


// set pins for VUMETER and the INPUT pots
//
int LEDS_VUMETER[6]  = { 10, 9, 8, 7, 6, 5  };
int AUDIO_INPUT = A0;
int SENSITIVITY_INPUT = A1;

 
void setup() {
  int i; // loop incrementor
  
  // set input ports
  pinMode(SENSITIVITY_INPUT, INPUT);
  pinMode(AUDIO_INPUT, INPUT);
 
  // set LED ports
  for (i = 0; i < 6; i++) {
    pinMode(LEDS_VUMETER[i], OUTPUT); 
    digitalWrite(LEDS_VUMETER[i], LOW);
  }
  
  // cycle all leds to ON
  for (i = 0; i < 6; i++) {
    digitalWrite(LEDS_VUMETER[i], HIGH);
    delay(25);
  }
  delay(500);
  
  // switch off all LEDs
  for (i = 5; i = 0; i--) {
    digitalWrite(LEDS_VUMETER[i], LOW);
    delay(25);
  }
  delay(1000);
}
 

void loop() {
  int i;  // loop incrementor
  
  int intensity = analogRead(SENSITIVITY_INPUT);
  int peak      = analogRead(AUDIO_INPUT);
  
  // divide peak by intensity, to allow adjustment on input volume
  peak  = peak / intensity;
  
  // don't allow peaks > 6
  if( peak > 6 ) peak = 6;
 
  // switch off LEDs if no signal is applied
  if (peak == 0) {
    for(i = 0; i < 6; i++) {
      digitalWrite(LEDS_VUMETER[i], LOW);
    }
    
  // otherwise, do the LED magic
  } else  {
    // switch LEDs on based on measured peak
    for (i = 0; i < peak; i++) {
     digitalWrite(LEDS_VUMETER[i], HIGH);
     delay(i*5);
    }
    
    // switch LEDs off in reverse order
    for(i = peak; i = 0; i--) {
      delay(i*2);
      digitalWrite(LEDS_VUMETER[i], LOW);
    }
  }

}

